@@ -20,8 +20,7 @@ from typing import Tuple, Union, List, Optional
 from warnings import warn
 from copy import copy
 import numpy as np
-from scipy.sparse.csr import csr_matrix
-from scipy.sparse import issparse, diags
+from scipy.sparse import csr_matrix, issparse, diags
 
 from qiskit import QiskitError
 from qiskit.quantum_info.operators import Operator
@@ -43,11 +42,10 @@ except ImportError:
 
 
 class BaseGeneratorModel(ABC):
-    r"""Defines an interface for a time-dependent
-    linear differential equation of the form :math:`\dot{y}(t) = \Lambda(t, y)`,
-    where :math:`\Lambda` is linear in :math:`y`. The core functionality is
-    evaluation of :math:`\Lambda(t, y)`, as well as,
-    if possible, evaluation of the map :math:`\Lambda(t, \cdot)`.
+    r"""Defines an interface for a time-dependent linear differential equation of the form
+    :math:`\dot{y}(t) = \Lambda(t, y)`, where :math:`\Lambda` is linear in :math:`y`. The core
+    functionality is evaluation of :math:`\Lambda(t, y)`, as well as, if possible, evaluation of the
+    map :math:`\Lambda(t, \cdot)`.
 
     Additionally, the class defines interfaces for:
 
@@ -62,19 +60,17 @@ class BaseGeneratorModel(ABC):
     @property
     @abstractmethod
     def dim(self) -> int:
-        """Gets matrix dimension."""
+        """The matrix dimension."""
 
     @property
     @abstractmethod
     def rotating_frame(self) -> RotatingFrame:
-        """Get the rotating frame."""
+        """The rotating frame."""
 
     @rotating_frame.setter
     @abstractmethod
     def rotating_frame(self, rotating_frame: RotatingFrame):
-        """Set the rotating frame; either an already instantiated :class:`RotatingFrame` object,
-        or a valid argument for the constructor of :class:`RotatingFrame`.
-        """
+        pass
 
     @property
     @abstractmethod
@@ -84,7 +80,7 @@ class BaseGeneratorModel(ABC):
     @in_frame_basis.setter
     @abstractmethod
     def in_frame_basis(self, in_frame_basis: bool):
-        """Set whether to evaluate in the basis in which the frame is diagonalized."""
+        pass
 
     @property
     @abstractmethod
@@ -94,14 +90,14 @@ class BaseGeneratorModel(ABC):
     @evaluation_mode.setter
     @abstractmethod
     def evaluation_mode(self, new_mode: str):
-        """Sets evaluation mode of model."""
+        pass
 
     @abstractmethod
     def evaluate(self, time: float) -> Array:
         r"""If possible, evaluate the map :math:`\Lambda(t, \cdot)`.
 
         Args:
-            time: Time.
+            time: The time to evaluate the model at.
         """
 
     @abstractmethod
@@ -109,7 +105,7 @@ class BaseGeneratorModel(ABC):
         r"""Evaluate the right hand side :math:`\dot{y}(t) = \Lambda(t, y)`.
 
         Args:
-            time: Time.
+            time: The time to evaluate the model at.
             y: State of the differential equation.
         """
 
@@ -118,29 +114,24 @@ class BaseGeneratorModel(ABC):
         return copy(self)
 
     def __call__(self, time: float, y: Optional[Array] = None) -> Array:
-        r"""Evaluate generator RHS functions. If ``y is None``,
-        attemps to evaluate :math:`\Lambda(t, \cdot)`, otherwise, calculates
-        :math:`\Lambda(t, y)`
+        r"""Evaluate generator RHS functions. If ``y is None``, attemps to evaluate
+        :math:`\Lambda(t, \cdot)`, otherwise, calculates :math:`\Lambda(t, y)`.
 
         Args:
-            time: Time.
+            time: The time to evaluate at.
             y: Optional state.
 
         Returns:
-            Array: Either the evaluated model or the RHS for the given y
+            Array: Either the evaluated model, or the RHS for the given y.
         """
-
-        if y is None:
-            return self.evaluate(time)
-
-        return self.evaluate_rhs(time, y)
+        return self.evaluate(time) if y is None else self.evaluate_rhs(time, y)
 
 
 class GeneratorModel(BaseGeneratorModel):
     r"""A model for a a linear matrix differential equation in standard form.
 
-    :class:`GeneratorModel` is a concrete instance of :class:`BaseGeneratorModel`, where the
-    map :math:`\Lambda(t, y)` is explicitly constructed as:
+    :class:`GeneratorModel` is a concrete instance of :class:`BaseGeneratorModel`, where the map
+    :math:`\Lambda(t, y)` is explicitly constructed as:
 
     .. math::
 
@@ -148,10 +139,9 @@ class GeneratorModel(BaseGeneratorModel):
 
         G(t) = \sum_i s_i(t) G_i + G_d
 
-    where the :math:`G_i` are matrices (represented by :class:`Operator`
-    or :class:`Array` objects), the :math:`s_i(t)` are signals represented by
-    a list of :class:`Signal` objects, and
-    :math:`G_d` is the constant-in-time static term of the generator.
+    where the :math:`G_i` are matrices (represented by :class:`Operator` or :class:`Array` objects),
+    the :math:`s_i(t)` are signals represented by a list of :class:`Signal` objects, and :math:`G_d`
+    is the constant-in-time static term of the generator.
     """
 
     def __init__(
@@ -171,19 +161,17 @@ class GeneratorModel(BaseGeneratorModel):
             signals: Stores the terms :math:`s_i(t)`. While required for evaluation,
                 :class:`GeneratorModel` signals are not required at instantiation.
             rotating_frame: Rotating frame operator.
-            in_frame_basis: Whether to represent the model in the basis in which the rotating
-                frame operator is diagonalized.
-            evaluation_mode: Evaluation mode to use.  Supported options are
-                ``'dense'`` and ``'sparse'``. Call ``help(GeneratorModel.evaluation_mode)``
-                for more details.
+            in_frame_basis: Whether to represent the model in the basis in which the rotating frame
+                operator is diagonalized.
+            evaluation_mode: Evaluation mode to use. Supported options are ``'dense'`` and
+                ``'sparse'``. Call ``help(GeneratorModel.evaluation_mode)`` for more details.
         Raises:
             QiskitError: If model not sufficiently specified.
         """
         if static_operator is None and operators is None:
             raise QiskitError(
-                self.__class__.__name__
-                + """ requires at least one of static_operator or operators to be
-                              specified at construction."""
+                f"{type(self).__name__} requires at least one of static_operator or operators to "
+                "be specified at construction."
             )
 
         # initialize internal operator representation
@@ -205,38 +193,29 @@ class GeneratorModel(BaseGeneratorModel):
 
     @property
     def dim(self) -> int:
-        if self._operator_collection.static_operator is not None:
-            return self._operator_collection.static_operator.shape[-1]
-        else:
-            return self._operator_collection.operators[0].shape[-1]
+        """The matrix dimension."""
+        return self._operator_collection.dim
 
     @property
     def evaluation_mode(self) -> str:
         """Numerical evaluation mode of the model.
 
-        Available options:
+        Possible values:
 
-         * 'dense': Stores/evaluates operators using dense Arrays.
-         * 'sparse': Stores/evaluates operators using sparse matrices. If
-           the default Array backend is JAX, implemented with JAX BCOO arrays,
-           otherwise uses scipy :class:`csr_matrix` sparse type. Note that
-           JAX sparse mode is only recommended for use on CPU.
+         * ``"dense"``: Stores/evaluates operators using dense Arrays.
+         * ``"sparse"``: Stores/evaluates operators using sparse matrices. If the default Array
+           backend is JAX, implemented with JAX BCOO arrays, otherwise uses scipy
+           :class:`csr_matrix` sparse type. Note that JAX sparse mode is only recommended for use on
+           CPU.
+
+        Raises:
+            NotImplementedError: If, when being set, ``new_mode`` is not one of the above supported
+            evaluation modes.
         """
         return self._evaluation_mode
 
     @evaluation_mode.setter
     def evaluation_mode(self, new_mode: str):
-        """Set evaluation mode.
-
-        Args:
-            new_mode: String specifying new mode. Available options
-                      are 'dense' and 'sparse'. See property doc string for details.
-
-        Raises:
-            NotImplementedError: if new_mode is not one of the above
-            supported evaluation modes.
-        """
-
         if new_mode != self._evaluation_mode:
             self._operator_collection = construct_operator_collection(
                 new_mode,
@@ -247,7 +226,13 @@ class GeneratorModel(BaseGeneratorModel):
 
     @property
     def rotating_frame(self) -> RotatingFrame:
-        """Return the rotating frame."""
+        """The rotating frame.
+
+        This property can be set with a :class:`RotatingFrame` instance, or any valid constructor
+        argument to this class.
+
+        Setting this property updates the internal operator to use the new frame.
+        """
         return self._rotating_frame
 
     @rotating_frame.setter
@@ -273,13 +258,16 @@ class GeneratorModel(BaseGeneratorModel):
 
     @property
     def signals(self) -> SignalList:
-        """Return the signals in the model."""
+        """The signals in the model.
+
+        Raises:
+            QiskitError: If set to ``None`` when operators exist, or when set to a number of signals
+                different then the number of operators.
+        """
         return self._signals
 
     @signals.setter
     def signals(self, signals: Union[SignalList, List[Signal]]):
-        """Set the signals."""
-
         if signals is None:
             self._signals = None
         elif signals is not None and self.operators is None:
@@ -305,9 +293,7 @@ class GeneratorModel(BaseGeneratorModel):
 
     @property
     def in_frame_basis(self) -> bool:
-        """Whether to represent the model in the basis in which the frame operator
-        is diagonalized.
-        """
+        """Whether the model is represented in the basis that diagonalizes the frame operator."""
         return self._in_frame_basis
 
     @in_frame_basis.setter
@@ -316,17 +302,16 @@ class GeneratorModel(BaseGeneratorModel):
 
     @property
     def operators(self) -> Array:
-        """Get the operators in the model."""
+        """The operators in the model."""
         return self._get_operators(in_frame_basis=self._in_frame_basis)
 
     @property
     def static_operator(self) -> Array:
-        """Get the static operator."""
+        """The static operator."""
         return self._get_static_operator(in_frame_basis=self._in_frame_basis)
 
     @static_operator.setter
     def static_operator(self, static_operator: Array):
-        """Set the static operator."""
         self._set_static_operator(
             new_static_operator=static_operator, operator_in_frame_basis=self._in_frame_basis
         )
@@ -338,41 +323,39 @@ class GeneratorModel(BaseGeneratorModel):
             in_frame_basis: Flag indicating whether to return the operators
             in the basis in which the rotating frame operator is diagonal.
         Returns:
-            The operators in the basis specified by `in_frame_basis`.
+            The operators in the basis specified by ``in_frame_basis``.
         """
         ops = self._operator_collection.operators
         if ops is not None and not in_frame_basis and self.rotating_frame is not None:
             return self.rotating_frame.operator_out_of_frame_basis(ops)
-        else:
-            return ops
+        return ops
 
     def _get_static_operator(self, in_frame_basis: Optional[bool] = False) -> Array:
         """Get the constant term.
 
         Args:
-            in_frame_basis: Flag for whether the returned static_operator should be
-            in the basis in which the frame is diagonal.
+            in_frame_basis: Whether the returned static_operator should be in the basis in which the
+                frame is diagonal.
         Returns:
             The static operator term.
         """
         op = self._operator_collection.static_operator
         if not in_frame_basis and self.rotating_frame is not None:
             return self.rotating_frame.operator_out_of_frame_basis(op)
-        else:
-            return op
+        return op
 
     def _set_static_operator(
         self,
         new_static_operator: Array,
         operator_in_frame_basis: Optional[bool] = False,
     ):
-        """Sets static term. Note that if the model has a rotating frame this will override
-        any contributions to the static term due to the frame transformation.
+        """Sets static term. Note that if the model has a rotating frame this will override any
+        contributions to the static term due to the frame transformation.
 
         Args:
             new_static_operator: The static operator operator.
-            operator_in_frame_basis: Whether `new_static_operator` is already in the rotating
-            frame basis.
+            operator_in_frame_basis: Whether `new_static_operator` is already in the rotating frame
+                basis.
         """
         if new_static_operator is None:
             self._operator_collection.static_operator = None
@@ -388,28 +371,21 @@ class GeneratorModel(BaseGeneratorModel):
         """Evaluate the model in array format as a matrix, independent of state.
 
         Args:
-            time: Time to evaluate the model.
+            time: The time to evaluate the model at.
 
         Returns:
-            Array: the evaluated model as a (n,n) matrix
+            Array: The evaluated model as a matrix.
 
         Raises:
             QiskitError: If model cannot be evaluated.
         """
-
-        if self._signals is None:
-            if self._operator_collection.operators is not None:
-                raise QiskitError(
-                    self.__class__.__name__
-                    + " with non-empty operators cannot be evaluated without signals."
-                )
-
-            sig_vals = None
-        else:
-            sig_vals = self._signals.__call__(time)
+        if self._signals is None and self._operator_collection.operators is not None:
+            raise QiskitError(
+                f"{type(self).__name__} with non-empty operators must be evaluated signals."
+            )
 
         # Evaluated in frame basis, but without rotations
-        op_combo = self._operator_collection(sig_vals)
+        op_combo = self._operator_collection(self._signals(time) if self._signals else None)
 
         # Apply rotations e^{-Ft}Ae^{Ft} in frame basis where F = D
         return self.rotating_frame.operator_into_frame(
@@ -417,10 +393,10 @@ class GeneratorModel(BaseGeneratorModel):
         )
 
     def evaluate_rhs(self, time: float, y: Array) -> Array:
-        r"""Evaluate `G(t) @ y`.
+        r"""Evaluate ``G(t) @ y``.
 
         Args:
-            time: Time to evaluate the model.
+            time: The time to evaluate the model at .
             y: Array specifying system state.
 
         Returns:
@@ -429,14 +405,11 @@ class GeneratorModel(BaseGeneratorModel):
         Raises:
             QiskitError: If model cannot be evaluated.
         """
-
         if self._signals is None:
             if self._operator_collection.operators is not None:
                 raise QiskitError(
-                    self.__class__.__name__
-                    + " with non-empty operators cannot be evaluated without signals."
+                    f"{type(self).__name__} with non-empty operators must be evaluated signals."
                 )
-
             sig_vals = None
         else:
             sig_vals = self._signals.__call__(time)
@@ -452,10 +425,9 @@ class GeneratorModel(BaseGeneratorModel):
             out = self.rotating_frame.state_into_frame(
                 time, out, y_in_frame_basis=True, return_in_frame_basis=self._in_frame_basis
             )
-        else:
-            return self._operator_collection(sig_vals, y)
+            return out
 
-        return out
+        return self._operator_collection(sig_vals, y)
 
 
 def transfer_static_operator_between_frames(
@@ -463,11 +435,11 @@ def transfer_static_operator_between_frames(
     new_frame: Optional[Union[Array, RotatingFrame]] = None,
     old_frame: Optional[Union[Array, RotatingFrame]] = None,
 ) -> Tuple[Union[None, Array]]:
-    """Helper function for transforming the static operator for a model from one
-    frame basis into another.
+    """Helper function for transforming the static operator of a model from one frame basis into
+    another.
 
-    ``static_operator`` is additionally transformed as a generator: the old frame operator is
-    added, and the new one is subtracted.
+    ``static_operator`` is additionally transformed as a generator: the old frame operator is added,
+    and the new one is subtracted.
 
     Args:
         static_operator: Static operator of the model. None is treated as 0.
@@ -527,11 +499,11 @@ def transfer_operators_between_frames(
     new_frame: Optional[Union[Array, RotatingFrame]] = None,
     old_frame: Optional[Union[Array, RotatingFrame]] = None,
 ) -> Tuple[Union[None, Array]]:
-    """Helper function for transforming a list of operators for a model
-    from one frame basis into another.
+    """Helper function for transforming a list of operators for a model from one frame basis into
+    another.
 
     Args:
-        operators: Operators of the model. If None, remains as None.
+        operators: Operators of the model. If ``None``, remains as ``None``.
         new_frame: New rotating frame.
         old_frame: Old rotating frame.
 
@@ -567,7 +539,7 @@ def construct_operator_collection(
     static_operator: Union[None, Array, csr_matrix],
     operators: Union[None, Array, List[csr_matrix]],
 ) -> BaseOperatorCollection:
-    """Construct operator collection for GeneratorModel.
+    """Construct an operator collection for :class:`GeneratorModel`.
 
     Args:
         evaluation_mode: Evaluation mode.
@@ -578,7 +550,7 @@ def construct_operator_collection(
         BaseOperatorCollection: The relevant operator collection.
 
     Raises:
-        NotImplementedError: If the evaluation_mode is invalid.
+        NotImplementedError: If the ``evaluation_mode`` is invalid.
     """
 
     if evaluation_mode == "dense":
@@ -596,7 +568,6 @@ def construct_operator_collection(
         return SparseOperatorCollection(static_operator=static_operator, operators=operators)
 
     raise NotImplementedError(
-        "Evaluation mode '"
-        + str(evaluation_mode)
-        + "' is not supported. Call help(GeneratorModel.evaluation_mode) for available options."
+        f"Evaluation mode '{evaluation_mode}' is not supported. Call "
+        "help(GeneratorModel.evaluation_mode) for available options."
     )
