@@ -30,21 +30,17 @@ from qiskit_dynamics.type_utils import to_array
 
 
 def rotating_wave_approximation(
-    model: BaseGeneratorModel,
-    cutoff_freq: float,
-    return_signal_map: Optional[bool] = False,
+    model: BaseGeneratorModel, cutoff_freq: float, return_signal_map: Optional[bool] = False
 ) -> BaseGeneratorModel:
-    r"""Construct a new model by performing the rotating wave approximation with a
-    given cutoff frequency. The outputs of this function can be used in JAX-transformable
-    functions, however this function itself cannot (see below).
+    r"""Construct a new model by performing the rotating wave approximation with a given cutoff
+    frequency. The outputs of this function can be used in JAX-transformable functions, however this
+    function itself cannot (see below).
 
-    Performs elementwise rotating wave approximation (RWA) with
-    cutoff frequency ``cutoff_freq`` on each operator in a model, returning a new model.
-    The new model contains a modified list of signal coefficients,
-    and setting the optional argument ``return_signal_map=True`` results in
-    the additional return of the function ``f`` which maps the signals
-    of the input model to those of the output RWA model, such that the
-    code blocks:
+    Performs elementwise rotating wave approximation (RWA) with cutoff frequency ``cutoff_freq`` on
+    each operator in a model, returning a new model. The new model contains a modified list of
+    signal coefficients, and setting the optional argument ``return_signal_map=True`` results in
+    the additional return of the function ``f`` which maps the signals of the input model to those
+    of the output RWA model, such that the code blocks:
 
     .. code-block:: python
 
@@ -91,40 +87,41 @@ def rotating_wave_approximation(
                 rwa_model_copy.signals = signal_map(new_signals)
                 return rwa_model_copy(t)
 
-        In this way, the outputs of ``rotating_wave_approximation`` can be used in
-        JAX-transformable functions, however ``rotating_wave_approximation`` itself cannot.
+        In this way, the outputs of ``rotating_wave_approximation`` can be used in JAX-transformable
+        functions, however ``rotating_wave_approximation`` itself cannot.
 
 
-    Formalism: When considering :math:`s_i(t) e^{-tF}G_ie^{tF}`, in the basis in which
-    :math:`F` is diagonal, the :math:`(j, k)` element of :math:`G_i` has effective frequency
-    :math:`\tilde\nu_{ijk}^\pm = \pm\nu_i + Im[-d_j+d_k]/2\pi`, where the :math:`\pm\nu_i`
-    comes from expressing
-    :math:`s_i(t) = Re[a_i(t)e^{2\pi i\nu_i t}] = a_i(t)e^{i(2\pi\nu_i t+\phi_i)}/2 + c.c.`
-    and the other term comes from the rotating frame. Define :math:`G_i^\pm` the matrix whose
-    entries :math:`(G_i^\pm)_{jk}` are the entries of :math:`G_i` s.t.
-    :math:`|\nu_{ijk}^\pm|<\nu_*` for some
-    cutoff frequency :math:`\nu_*`. Then, after the RWA, we may write
+    We now describe the formalism. When considering :math:`s_i(t) e^{-tF}G_ie^{tF}`, in the basis in
+    which :math:`F` is diagonal, the :math:`(j, k)` element of :math:`G_i` has effective frequency
+    :math:`\tilde\nu_{ijk}^\pm = \pm\nu_i + Im[-d_j+d_k]/2\pi`, where the :math:`\pm\nu_i` comes
+    from expressing :math:`s_i(t) = Re[a_i(t)e^{2\pi i\nu_i t}] = a_i(t)e^{i(2\pi\nu_i t+\phi_i)}/2
+    + c.c.` and the other term comes from the rotating frame. Define :math:`G_i^\pm` the matrix
+    whose entries :math:`(G_i^\pm)_{jk}` are the entries of :math:`G_i` s.t.
+    :math:`|\nu_{ijk}^\pm|<\nu_*` for some cutoff frequency :math:`\nu_*`. Then, after the RWA, we
+    may write
 
     .. math::
         s_i(t)G_i \to G_i^+ a_ie^{i(2\pi \nu_i t+\phi_i)}/2
                         + G_i^- \overline{a_i}e^{-i(2\pi \nu_i t+\phi_i)}/2.
 
-    When we regroup these to use only the real components of Signal objects, we find that
+    When we regroup these to use only the real components of the signal, we find that
 
     .. math::
         s_i(t)G_i \to  s_i(t)(G_i^+ + G_i^-)/2 + s_i'(t)(iG_i^+-iG_i^-)
 
-    where :math:`s_i'(t)` is a Signal with the same frequency and amplitude as :math:`s_i`,
-    but with a phase shift of :math:`\phi_i - \pi/2`.
+    where :math:`s_i'(t)` is a signal with the same frequency and amplitude as :math:`s_i`, but with
+    a phase shift of :math:`\phi_i - \pi/2`.
 
     Args:
         model: The model to approximate.
         cutoff_freq: The cutoff frequency for the approximation.
-        return_signal_map: Whether to also return the function for mapping
-                           pre-RWA signals to post-RWA signals.
+        return_signal_map: Whether to also return the function for mapping pre-RWA signals to
+            post-RWA signals.
+
     Returns:
-        GeneratorModel with twice as many terms, and, if return_signal_map,
-        also the function f.
+        :class:`GeneratorModel` with twice as many terms, and, if ``return_signal_map``,
+        also the function ``f``.
+
     Raises:
         ValueError: If the model has no signals.
     """
@@ -244,23 +241,22 @@ def get_rwa_operators(
     frame_freqs: Array,
     cutoff_freq: float,
 ):
-    r"""Given a set of operators as a (k,n,n) Array, a set of
-    frequencies (frame_freqs)_{jk} = Im[-d_j+d_k] where d_i
-    the i^{th} eigenlvalue of the frame operator F, the current
-    signals of a model, and a cutoff frequency, returns
-    the new operators and signals that should be passed to
-    create a new Model class after the RWA.
+    r"""Given a set of operators as a ``(k,n,n)`` array, a set of frequencies
+    :math:`\operatorname{frame_freqs}_{jk} = \operatorname{Im}[-d_j+d_k]` where :math:`d_i` the
+    :math:`i^{th}` eigenlvalue of the frame operator :math:`F`, the current signals of a model, and
+    a cutoff frequency, returns the new operators and signals that should be passed to create a new
+    Model class after the RWA.
 
     Args:
-        current_ops: the current operator list, (k,n,n) Array
-        current_sigs: (k) length SignalList
-        rotating_frame: current RotatingFrame object of the pre-RWA model
-        frame_freqs: the effective frequencies of different
-            matrix elements due to the conjugation by e^{\pm Ft}
-            in the rotating frame.
-        cutoff_freq: maximum frequency allowed under the RWA.
+        current_ops: The current operator list, a ``(k,n,n)`` array.
+        current_sigs: ``(k,)`` length :class:`SignalList`.
+        rotating_frame: The current :class:`~RotatingFrame` object of the pre-RWA model
+        frame_freqs: The effective frequencies of different matrix elements due to the conjugation
+            by :math:`e^{\pm Ft}` in the rotating frame.
+        cutoff_freq: The maximum frequency allowed under the RWA.
+
     Returns:
-        SignaLList: (2k,n,n) Array of new operators post RWA.
+        SignaLList: ``(2k,n,n)`` array of new operators post RWA.
     """
     if current_ops is None:
         return None
@@ -287,16 +283,20 @@ def get_rwa_operators(
     real_component = pos_terms / 2 + neg_terms / 2
     imag_component = 1j * pos_terms / 2 - 1j * neg_terms / 2
 
-    rwa_operators = rotating_frame.operator_out_of_frame_basis(
+    return rotating_frame.operator_out_of_frame_basis(
         np.append(real_component, imag_component, axis=0)
     )
 
-    return rwa_operators
-
 
 def get_rwa_signals(curr_signal_list: Union[List[Signal], SignalList]):
-    """Helper function that converts pre-RWA
-    signals to post-RWA signals"""
+    """Helper function that converts pre-RWA signals to post-RWA signals.
+
+    Args:
+        curr_signal_list: The pre-RWA signals.
+
+    Returns:
+        The post-RWA signals.
+    """
     if curr_signal_list is None:
         return curr_signal_list
 
@@ -315,6 +315,4 @@ def get_rwa_signals(curr_signal_list: Union[List[Signal], SignalList]):
             SignalSum(Signal(sig.envelope, sig.carrier_freq, sig.phase - np.pi / 2))
         )
 
-    rwa_signals = SignalList(real_signal_components + imag_signal_components)
-
-    return rwa_signals
+    return SignalList(real_signal_components + imag_signal_components)
