@@ -95,7 +95,6 @@ class Signal:
             envelope = Array(complex(envelope))
 
         if isinstance(envelope, Array):
-
             # if envelope is constant and the carrier is zero, this is a constant signal
             if carrier_freq == 0.0:
                 self._is_constant = True
@@ -494,7 +493,7 @@ class SignalCollection:
     def __getitem__(
         self, idx: Union[int, List, np.array, slice]
     ) -> Union[Signal, "SignalCollection"]:
-        """Get item with Numpy-style subscripting, as if this class were a 1d array."""
+        """Get item with NumPy-style subscripting, as if this class were a 1d array."""
 
         if type(idx) == np.ndarray and idx.ndim > 0:
             idx = list(idx)
@@ -672,6 +671,7 @@ class DiscreteSignalSum(DiscreteSignal, SignalSum):
             name: name of the signal.
         """
 
+        samples = Array(samples)
         if carrier_freq is None:
             carrier_freq = np.zeros(samples.shape[-1], dtype=float)
 
@@ -818,7 +818,6 @@ class SignalList(SignalCollection):
     """
 
     def __init__(self, signal_list: List[Signal]):
-
         signal_list = [to_SignalSum(signal) for signal in signal_list]
 
         super().__init__(signal_list)
@@ -1134,9 +1133,13 @@ def to_SignalSum(sig: Union[int, float, complex, Array, Signal]) -> SignalSum:
     if isinstance(sig, (int, float, complex)) or (isinstance(sig, Array) and sig.ndim == 0):
         return SignalSum(Signal(sig))
     elif isinstance(sig, DiscreteSignal) and not isinstance(sig, DiscreteSignalSum):
+        if Array(sig.samples.data).shape == (0,):
+            new_samples = Array([sig.samples.data])
+        else:
+            new_samples = Array([sig.samples.data]).transpose(1, 0)
         return DiscreteSignalSum(
             dt=sig.dt,
-            samples=Array([sig.samples.data]).transpose(1, 0),
+            samples=new_samples,
             start_time=sig.start_time,
             carrier_freq=Array([sig.carrier_freq.data]),
             phase=Array([sig.phase.data]),
