@@ -26,6 +26,12 @@ from qiskit import QiskitError
 from qiskit_dynamics.array import Array
 from qiskit_dynamics.models import LindbladModel
 
+try:
+    from jax.lax import cond
+    import jax.numpy as jnp
+except ImportError:
+    pass
+
 
 def is_lindblad_model_vectorized(obj: any) -> bool:
     """Return True if obj is a vectorized LindbladModel."""
@@ -40,15 +46,13 @@ def is_lindblad_model_not_vectorized(obj: any) -> bool:
 def merge_t_args(
     t_span: Union[List, Tuple, Array], t_eval: Optional[Union[List, Tuple, Array]] = None
 ) -> Union[List, Tuple, Array]:
-    """Merge ``t_span`` and ``t_eval`` into a single array without
-    duplicates. Validity of the passed ``t_span`` and ``t_eval``
-    follow scipy ``solve_ivp`` validation logic:
-    ``t_eval`` must be contained in ``t_span``, and be strictly
-    increasing if ``t_span[1] > t_span[0]`` or strictly
-    decreasing if ``t_span[1] < t_span[0]``.
+    """Merge ``t_span`` and ``t_eval`` into a single array.
 
-    Note: this is done explicitly with ``numpy``, and hence this is
-    not differentiable or compilable using jax.
+    Validition is similar to scipy ``solve_ivp``: ``t_eval`` must be contained in ``t_span``, and be
+    increasing if ``t_span[1] > t_span[0]`` or decreasing if ``t_span[1] < t_span[0]``.
+
+    Note: this is done explicitly with ``numpy``, and hence this is not differentiable or compilable
+    using jax.
 
     If ``t_eval is None`` returns ``t_span`` with no modification.
 
@@ -82,30 +86,24 @@ def merge_t_args(
 
     diff = np.diff(t_eval)
 
-    if np.any(t_direction * diff <= 0.0):
+    if np.any(t_direction * diff < 0.0):
         raise ValueError("t_eval must be ordered according to the direction of integration.")
 
-    # if endpoints are not included in t_span, add them
-    if t_eval[0] != t_span[0]:
-        t_eval = np.append(t_span[0], t_eval)
-
-    if t_span[1] != t_eval[-1]:
-        t_eval = np.append(t_eval, t_span[1])
+    # add endpoints
+    t_eval = np.append(np.append(t_span[0], t_eval), t_span[1])
 
     return Array(t_eval, backend="numpy")
 
 
 def trim_t_results(
     results: OdeResult,
-    t_span: Union[List, Tuple, Array],
     t_eval: Optional[Union[List, Tuple, Array]] = None,
 ) -> OdeResult:
-    """Trim ``OdeResult`` object based on value of ``t_span`` and ``t_eval``.
+    """Trim ``OdeResult`` object if ``t_eval is not None``.
 
     Args:
         results: Result object, assumed to contain solution at time points
-                 from the output of ``validate_and_merge_t_span_t_eval(t_span, t_eval)``.
-        t_span: Interval to solve over.
+                 from the output of ``merge_t_args(t_span, t_eval)``.
         t_eval: Time points to include in returned results.
 
     Returns:
@@ -116,16 +114,125 @@ def trim_t_results(
     if t_eval is None:
         return results
 
-    t_span = Array(t_span, backend="numpy")
+    # remove endpoints
+    results.t = results.t[1:-1]
+    results.y = Array(results.y[1:-1])
 
-    # remove endpoints if not included in t_eval
-    if t_eval[0] != t_span[0]:
-        results.t = results.t[1:]
-        results.y = Array(results.y[1:])
+    return results
 
-    if t_eval[-1] != t_span[1]:
-        results.t = results.t[:-1]
-        results.y = Array(results.y[:-1])
+
+def merge_t_args_jax(
+    t_span: Union[List, Tuple, Array], t_eval: Optional[Union[List, Tuple, Array]] = None
+) -> Union[List, Tuple, Array]:
+    """JAX-compilable version of merge_t_args.
+
+    Rather than raise errors, sets return values to ``jnp.nan`` to signal errors.
+    The merging strategy differs from :func:`merge_t_args`: after appending
+    the endpoints of ``t_span`` to ``t_eval``, it is checked whether the first two entries
+    of the resulting array are equal. If they are, the second entry is set to the average
+    of the first and the third. A similar procedure is done for the last two entries. This is
+    essentially a hack to to avoid adjacent entries of the combined ``t_span``, ``t_eval``
+    array having equal values, which causes buggy behaviour in :func:`jax_odeint`.
+
+    Args:
+        t_span: Interval to solve over. Assumed to be a list, tuple, or Array with 2 entries.
+        t_eval: Time points to include in returned results.
+
+    Returns:
+        Union[List, Tuple, Array]: Combined list of times.
+
+    Raises:
+        ValueError: If either argument is not one dimensional.
+    """
+
+    if t_eval is None:
+        return Array(t_span, backend="jax")
+
+    t_span = Array(t_span, backend="jax").data
+    t_eval = Array(t_eval, backend="jax").data
+
+    # raise error if not one dimensional
+    if t_eval.ndim > 1:
+        raise ValueError("t_eval must be 1 dimensional.")
+
+    out = jnp.append(jnp.append(t_span[0], t_eval), t_span[1])
+
+    # output nan if t_eval point lies outside t_span
+    t_min = jnp.min(t_span)
+    t_max = jnp.max(t_span)
+    out = cond(
+        (jnp.min(t_eval) < t_min) | (jnp.max(t_eval) > t_max),
+        lambda s: jnp.nan * s,
+        lambda s: s,
+        out,
+    )
+
+    # output nan if t_eval and t_span have incompatible orderings
+    diff = jnp.diff(t_eval)
+    t_direction = jnp.sign(t_span[1] - t_span[0])
+    out = cond(jnp.any(t_direction * diff < 0.0), lambda s: jnp.nan * s, lambda s: s, out)
+
+    # if out[0] == out[1], set out[1] == (out[2] + out[0])/2
+    out = cond(out[0] == out[1], lambda x: x.at[1].set((x[2] + x[0]) / 2), lambda x: x, out)
+
+    # if out[-1] == out[-2], set out[-2] == (out[-3] + out[-1])/2
+    out = cond(out[-1] == out[-2], lambda x: x.at[-2].set((x[-3] + x[-1]) / 2), lambda x: x, out)
+
+    return Array(out)
+
+
+def trim_t_results_jax(
+    results: OdeResult,
+    t_eval: Optional[Union[List, Tuple, Array]] = None,
+) -> OdeResult:
+    """JAX-compilable version of trim_t_results.
+
+    Note the choice of which entry to remove in the case of duplicate time entries is due to
+    peculiarities in :func:`jax_odeint`.
+
+    Args:
+        results: Result object, assumed to contain solution at time points from the output of
+            ``merge_t_args_jax(t_span, t_eval)``.
+        t_eval: Time points to include in returned results.
+
+    Returns:
+        OdeResult: Results with only times/solutions in ``t_eval``. If ``t_eval`` is ``None``,
+            returns solver default output, with an additional correction for the possibility of
+            ``t_span == [a, a]``.
+    """
+
+    if t_eval is not None:
+        # remove second entry if t_eval[0] == results.t[0], as this indicates a repeated time
+        results.y = Array(
+            cond(
+                t_eval[0] == results.t[0],
+                lambda y: jnp.append(jnp.array([y[0]]), y[2:], axis=0),
+                lambda y: y[1:],
+                Array(results.y).data,
+            )
+        )
+
+        # remove second last entry if t_eval[-1] == results.t[-1], as this indicates a repeated time
+        results.y = Array(
+            cond(
+                t_eval[-1] == results.t[-1],
+                lambda y: jnp.append(y[:-2], jnp.array([y[-1]]), axis=0),
+                lambda y: y[:-1],
+                Array(results.y).data,
+            )
+        )
+
+        results.t = Array(t_eval)
+
+    # this handles the odd case that t_span == [a, a]
+    results.y = Array(
+        cond(
+            results.t[0] == results.t[-1],
+            lambda y: y.at[-1].set(y[0]),
+            lambda y: y,
+            Array(results.y).data,
+        )
+    )
 
     return results
 
